var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import { createPortal, render, unmountComponentAtNode } from 'react-dom';
import Button from '../button/index';
import './style.scss';
var AlertComponent = function (props) {
    var title = props.title, desc = props.desc, onClose = props.onClose, btnDirection = props.btnDirection;
    var btns = props.btns;
    var onBtnClick = function (onClick, btn) {
        if (onClick === void 0) { onClick = function () { }; }
        return function () {
            onClick();
            onClose(btn);
        };
    };
    var renderBtns = function () {
        if (!btns || btns.length === 0) {
            btns = [{ name: '确定', capsule: true }];
        }
        var onlyBtn = btns.length <= 1;
        return btns.map(function (btn, index) {
            var name = btn.name, className = btn.className, onClick = btn.onClick, type = btn.type, value = btn.value, otherProps = __rest(btn, ["name", "className", "onClick", "type", "value"]);
            var btnType = type;
            if (typeof type === 'undefined') {
                if (onlyBtn) {
                    btnType = 'primary';
                }
                else {
                    btnType = index === 0 ? 'default' : 'primary';
                }
            }
            return (React.createElement(Button, __assign({}, otherProps, { className: className, type: btnType, key: index, capsule: true, onClick: onBtnClick(onClick, btn) }), name));
        });
    };
    return (React.createElement("div", { className: "x-alert__inner" },
        React.createElement("div", { className: "x-alert__body" },
            !!title && React.createElement("h1", null, title),
            React.createElement("div", { className: title ? 'desc' : 'desc no-title' }, desc)),
        React.createElement("div", { className: cn('x-alert__btns', {
                'x-alert__btns--column': btnDirection === 'column',
            }) }, renderBtns())));
};
var Alert = function (params, callback) {
    var div = document.createElement('div');
    div.classList.add('x-alert', 'x-alert--show');
    if (typeof params !== 'string' && params.className) {
        div.classList.add(params.className);
    }
    document.body.appendChild(div);
    var close = function (btn) {
        div.classList.remove('x-alert--show');
        div.classList.add('x-alert--hide');
        setTimeout(function () {
            if (div && div.parentNode) {
                unmountComponentAtNode(div);
                div.parentNode.removeChild(div);
            }
            if (callback && btn) {
                callback(btn.value);
            }
        }, 200);
    };
    if (typeof params === 'string') {
        render(createPortal(React.createElement(AlertComponent, { desc: params, onClose: close }), div), div);
    }
    else {
        render(createPortal(React.createElement(AlertComponent, __assign({}, params, { btns: params.btns, btnDirection: params.btnDirection, title: params.title || '', onClose: close })), div), div);
    }
    var resClose = close;
    return [resClose, void 0];
};
Alert.async = function (params) {
    return new Promise(function (resolve) {
        Alert(params, function (value) {
            resolve(value);
        });
    });
};
export default Alert;
