import dateFormat from './dateFormat';
var Model = /** @class */ (function () {
    function Model() {
        var _this = this;
        // 获取时间列表，并format格式
        this.getDayList = function (data, format) {
            if (format === void 0) { format = ['MM月dd日 周wk', 'h点', 'm分']; }
            var days = [];
            var dayFormat = format[0];
            if (Array.isArray(data)) {
                data.forEach(function (res) {
                    if (res.day && res.day instanceof Date) {
                        days.push(dateFormat(res.day, dayFormat));
                    }
                });
            }
            return days;
        };
        // 根据时间转换出state需要的数据
        this.getStateByTime = function (time, data) {
            var defDay;
            var defHH;
            var defMM;
            var hm = dateFormat(time, 'yyyy,MM,dd,hh,mm').split(',');
            defDay = new Date(Number(hm[0]), Number(hm[1]) - 1, Number(hm[2]));
            defHH = hm[3];
            defMM = hm[4];
            // 是否命中当天（就是datas数据有没有和t是在同一天的，如果没有，小时和分钟就全取默认第一项）
            var hasMatchDay = false;
            // 天
            var currentDayIndex = 0;
            var currentDayValue = data[0].day;
            if (defDay) {
                for (var i = 0; i < data.length; i++) {
                    if (data[i].day.valueOf() === defDay.valueOf()) {
                        currentDayIndex = i;
                        currentDayValue = data[i].day;
                        hasMatchDay = true;
                        break;
                    }
                }
            }
            // 小时
            var timeList = _this.getTimeList(data[currentDayIndex]);
            var times = _this.transTimeList(timeList);
            var currentHHIndex = 0;
            var currentHHValue = times.HHList[0];
            if (hasMatchDay && defHH) {
                times.HHList.forEach(function (i, index) {
                    if (i !== 'HHList' && i === defHH) {
                        currentHHIndex = index;
                        currentHHValue = i;
                    }
                });
            }
            // 分钟
            var currentMMIndex = 0;
            var mmList = times.MMList[times.HHList[currentHHIndex]];
            var currentMMValue = mmList ? mmList[0] : '00';
            if (hasMatchDay && defMM) {
                for (var i = 0; i < times.MMList[times.HHList[currentHHIndex]].length; i++) {
                    var d = times.MMList[times.HHList[currentHHIndex]][i];
                    if (d === defMM) {
                        currentMMIndex = i;
                        currentMMValue = d;
                        break;
                    }
                }
            }
            var res = {
                times: times,
                currentDayIndex: currentDayIndex,
                currentDayValue: currentDayValue,
                currentHHIndex: currentHHIndex,
                currentHHValue: currentHHValue,
                currentMMIndex: currentMMIndex,
                currentMMValue: currentMMValue,
                HHList: times.HHList,
                MMList: times.MMList[times.HHList[currentHHIndex]],
            };
            return res;
        };
        // 将时间和分钟分为两组数据，接收的数据格式为getTimeList方法返回的格式
        this.transTimeList = function (times) {
            var result = {
                HHList: [],
                MMList: {},
            };
            if (Array.isArray(times)) {
                times.forEach(function (item) {
                    var i = item.substr(0, 2);
                    var t = item.substr(2, 2);
                    if (!result.MMList[i]) {
                        result.MMList[i] = [t];
                        result.HHList.push(i);
                    }
                    else {
                        result.MMList[i].push(t);
                    }
                });
            }
            return result;
        };
        // 根据两个范围获取可用的时间
        // eg: getTimeRange(0215, 1200) 表示2:15至12点间的可用时间
        this.getTimeRange = function (start, end) {
            // 判断格式是否正确
            if (!/[0-9]{4}/.test(start) || !/[0-9]{4}/.test(end)) {
                return [];
            }
            // end要比start大
            if (Number(end) - Number(start) < 0) {
                return [];
            }
            // start和end一样
            if (start === end) {
                return [start];
            }
            // 获取判断的小时范围
            var hhStart = Math.min(Number(start.substr(0, 2)) - 0, _this.HHList.length - 1);
            var hhEnd = Math.min(Number(end.substr(0, 2)) - 0, _this.HHList.length - 1);
            var range = [];
            // 判断所有的时间并把在这个范围内的时间取出来
            for (var i = hhStart; i <= hhEnd; i++) {
                for (var _i = 0, _a = _this.MMList; _i < _a.length; _i++) {
                    var m = _a[_i];
                    var t = _this.HHList[i] + m;
                    if (i === hhStart || i === hhEnd) {
                        if (t >= start && t <= end) {
                            range.push(t);
                        }
                    }
                    else {
                        range.push(t);
                    }
                }
            }
            return range;
        };
        // 获取时间列表
        this.getTimeList = function (day) {
            var times = [];
            if (!day) {
                return times;
            }
            if (!Array.isArray(day.times)) {
                for (var _i = 0, _a = _this.HHList; _i < _a.length; _i++) {
                    var h = _a[_i];
                    for (var _b = 0, _c = _this.MMList; _b < _c.length; _b++) {
                        var m = _c[_b];
                        times.push(h + m);
                    }
                }
                return times;
            }
            if (day.times && day.times.length && Array.isArray(day.times[0])) {
                ;
                day.times.forEach(function (res) {
                    if (Array.isArray(res) && res.length === 2) {
                        var t = _this.getTimeRange(res[0], res[1]);
                        if (t) {
                            t.forEach(function (i) {
                                if (times.indexOf(i) === -1) {
                                    times.push(i);
                                }
                            });
                        }
                    }
                });
            }
            else if (day.times &&
                day.times.length === 2 &&
                typeof day.times[0] === 'string' &&
                typeof day.times[1] === 'string') {
                times = _this.getTimeRange(day.times[0], day.times[1]);
            }
            return times.sort(function (a, b) { return Number(a) - Number(b); });
        };
        this.HHList = [];
        this.MMList = [];
    }
    // 判断是否为整点时间
    Model.prototype.isZeroTime = function (date) {
        return date.getHours() + date.getMinutes() + date.getSeconds() + date.getMilliseconds() === 0;
    };
    return Model;
}());
export default new Model();
